defmodule DecentralisedBookIndex.Metadata.AuthorTest do
  use DecentralisedBookIndex.DataCase, async: true

  alias DecentralisedBookIndex.Metadata

  describe "authors and registries relationship" do
    test "a new author get new registry by default" do
      assert {:ok, author} = Metadata.create_author("Author", "An description")
      assert author.author_alias_registry_id != nil
    end

    test "a new author belongs to a registry if specified" do
      assert {:ok, registry} = Metadata.create_author_alias_registry()
      assert {:ok, author} = Metadata.create_author("Author", "An description", registry.id)
      assert author.author_alias_registry_id == registry.id
    end

    test "a new author to a registry via a related author record" do
      {:ok, related_author}  = Metadata.create_author("Author",  "An description")

      assert {:ok, author} =
        Metadata.add_author_to_related_alias_registry("Author2", "An description2", related_author.id)

      assert related_author.author_alias_registry_id == author.author_alias_registry_id
    end

    test "a new author to a registry via a empty related author record" do
      assert {:error, _} =
        Metadata.add_author_to_related_alias_registry("Author2", "An description2", nil)
    end
  end
end
